==> libremail-2.3.3.tar.bz2: libremail/src/cremail.c <==
/*
    Fichier cremail.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Ce programme permet de saisir un Email

    On peut choisir les destinataires  partir du carnet d'adresses
    ou en saisir de nouveaux

    Le fichier obtenu est ensuite stoqu dans le rpertoire des mails  envoyer
    Pour que cela soit possible, il faut :
    - soit que la commande cremail soit lance depuis la chaine vmail...
    - soit prciser le nom du rpertoire de l'arborescence des mails
*/

#define appli   // pour la dclaration de variables globales  l'application

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "messages.h"
#include "buflect.h"
#include "numail.h"
#include "genentete.h"
#include "modepage.h"
#include "carspe.h"


/* prototypes */
void gene_entete (char *sujetmail, char *nomfic);


/* variable globale au source
   (pour viter des passages de paramtres) */

long numail;  // numro que prendra le mail gnr


/* programme principal */

int main (int nbarg, char *varg[])
{
    char ficmail [szchemin]; // fichier mail de rponse
    char fentete [szchemin]; // fichier contenant l'entete du message
    char sujet [200];        // sujet du mail
    char commande [szchemin + 13];  // pour saisir le message
    char *editeur;           // diteur utilis pour saisir les mails
    unsigned long heuredeb;  // pour dtecter si on appelle un diteur graphique


    // rcupration du nom de l'excutable
    memcom (*varg);

    // on dmarre avec la configuration standard du clavier
    mode_normal ();

    // si nombre d'arguments correct
    if (nbarg <= 2)
        // rcuprer le nom du rpertoire des mails  envoyer
        recupdirenv (nbarg, varg [1]);
    else
        // sinon, rappel de la syntaxe de la commande
        // "Syntaxe : %s [rpertoire_emails]"
        psyntaxe ("SYNT_CREMAIL");

    // saisir le sujet du mail
    // "Sujet du mail : "
    printf (message ("SUJET_NOUVMAIL"));
    fgets (sujet, sizeof (sujet), stdin);

    // si sujet trop long pour rentrer dans le buffer
    if (sujet [strlen (sujet) - 1] != '\n')
    {
        // mettre le passage  la ligne manquant
        sujet [strlen (sujet) - 1] = '\n';

        // et ignorer la fin de ligne
        fflush (stdin);
    }

    // crer un nom de fichier temporaire pour le message
    // il a toujours le mme nom pour viter de polluer le
    // rpertoire d'envoi en cas de fausse manoeuvre oprateur
    sprintf (ficmail, "%s/tmp-mes", direnv);

    // Choix de l'diteur de textes
    editeur = getenv ("EDITOR");

    if (! editeur)
        editeur = "vi";

    // saisir le message

    // fabriquer la commande  xcuter
    sprintf (commande, "%s %s", editeur, ficmail);

    // rcuprer l'heure courante
    heuredeb = time (0);

    // lancer la commande
    system (commande);

    // si la commande a rendu la main trs rapidement
    if (time (0) <= heuredeb + 1)
    {
        // "Tapez sur la touche entre en cas d'erreur de lancement de"
        // "l'diteur ou aprs avoir sauv le mail depuis un diteur graphique"
        affiche_msg ("ATTENTE_ENTREE1");
        printf (message ("ATTENTE_ENTREE2"));

        // attendre confirmation de l'oprateur
        while (getchar () != '\n')
            ;
    }

    // sortie si arrt de la saisie
    if (access (ficmail, 0) < 0)
        // "Arrt de la saisie par l'oprateur"
        errfatale ("ARRET_SAISIE", 0);

    // charger le carnet d'adresses
    charge_carnet_adr ();

    // crer un nom de fichier temporaire pour l'entte du mail
    sprintf (fentete, "%s/tmp-ent", direnv);

    // fabriquer l'entte du mail de rponse
    gene_entete (sujet, fentete);

    // mmoriser les dates et heure d'envoi du message
    ajout_date (fentete);

    // on va regrouper l'entte et le message dans un fichier numrot dfinitif
    fusionner (fentete, numail, ficmail);

    // ajouter la signature au message, si elle existe
    ajout_sign (ficmail);

    // mettre  jour le fichier numail du rpertoire de sortie
    sauv_num_dermail (direnv, numail);

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}


/* gnre l'entte du mail que l'on transfre */

void gene_entete (char *sujetmail, char *nomfic)
{
    // fabriquer et ouvrir en criture le fichier d'entte
    fdest = fopen (nomfic, "w");

    if (! fdest)
        // "Impossible de crer un fichier d'entte %s"
        errfatale ("IMPOS_CRE_ENTETE", nomfic);

    // rcuprer l'adresse de l'expditeur
    lire_exped ();

    // chercher le numro du mail que l'on va crer
    numail = num_dermail (direnv) + 1;

    // gnration du champ Message-Id
    gen_mes_id (fdest, numail, buf_lect);

    // y copier l'expditeur du message
    ajouts = 0;
    ajout_adr (buf_lect, "From");
    fputc ('\n', fdest);

    // configurer la liaison clavier pour lecture directe avec timeout
    mode_raw ();

    // Choix des destinataires
    debpage ();
    effpage ();

    // "Destinataires principaux"
    affiche_msg ("PRINCIP_DEST");
    sleep (1);
    choixdest ("To");
    effpage ();

    // "Voulez vous mettre des destinataires en copie ? "
    printf (message ("ACCEPT_DEST_CC"));

    if (tolower (leccar ()) != 'n')
    {
        putchar ('\n');
        choixdest ("Cc");
    }
    else
        putchar ('\n');

    effpage ();
    // "Voulez vous mettre des destinataires en copie cache ? "
    printf (message ("ACCEPT_DEST_BCC"));

    if (tolower (leccar ()) != 'n')
    {
        putchar ('\n');
        choixdest ("Bcc");
    }

    putchar ('\n');
    effpage ();

    // retour  la configuration standard du clavier
    mode_normal ();

    // gnration du champ Subject
    fprintf (fdest, "Subject: %s", sujetmail);

    // jeu de caractres du message
    fprintf (fdest, "Content-Type: text/plain; charset=");

    if (util_utf8 ())
        fprintf (fdest, "UTF-8;\n");
    else
        fprintf (fdest, "ISO-8859-15;\n");

    // mode d'encodage
    fprintf (fdest, "Content-Transfer-Encoding: 8bit\n");

    // un copyright qui n'est pas celui d'Outlook ;-))
    // "libremail : logiciel libre multilingue"
    fprintf (fdest, "User-Agent: libremail : %s\n",
                     message ("QUALIF_LIBREMAIL"));

    // permettra de relire ce fichier
    fclose (fdest);
}

==> libremail-2.5.2.tar.bz2: libremail/src/cremail.c <==
/*
    Fichier cremail.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Ce programme permet de saisir un Email

    On peut choisir les destinataires  partir du carnet d'adresses
    ou en saisir de nouveaux

    Le fichier obtenu est ensuite stoqu dans le rpertoire des mails  envoyer
    Pour que cela soit possible, il faut :
    - soit que la commande cremail soit lance depuis la chaine vmail...
    - soit prciser le nom du rpertoire de l'arborescence des mails
*/

#define appli   // pour la dclaration de variables globales  l'application

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "messages.h"
#include "buflect.h"
#include "numail.h"
#include "genentete.h"
#include "modepage.h"
#include "carspe.h"


/* prototypes */
void gene_entete (char *sujetmail, char *nomfic);


/* variable globale au source
   (pour viter des passages de paramtres) */

long numail;  // numro que prendra le mail gnr


/* programme principal */

int main (int nbarg, char *varg[])
{
    char ficmail [szchemin]; // fichier mail de rponse
    char fentete [szchemin]; // fichier contenant l'entete du message
    char sujet [200];        // sujet du mail
    char commande [szchemin + 13];  // pour saisir le message
    char *editeur;           // diteur utilis pour saisir les mails
    unsigned long heuredeb;  // pour dtecter si on appelle un diteur graphique


    // rcupration du nom de l'excutable
    memcom (*varg);

    // on dmarre avec la configuration standard du clavier
    mode_normal ();

    // si nombre d'arguments correct
    if (nbarg <= 2)
        // rcuprer le nom du rpertoire des mails  envoyer
        recupdirenv (nbarg, varg [1]);
    else
        // sinon, rappel de la syntaxe de la commande
        // "Syntaxe : %s [rpertoire_emails]"
        psyntaxe ("SYNT_CREMAIL");

    // saisir le sujet du mail
    // "Sujet du mail : "
    affiche_msg_nocr ("SUJET_NOUVMAIL");
    fgets (sujet, sizeof (sujet), stdin);

    // si sujet trop long pour rentrer dans le buffer
    if (sujet [strlen (sujet) - 1] != '\n')
    {
        // mettre le passage  la ligne manquant
        sujet [strlen (sujet) - 1] = '\n';

        // et ignorer la fin de ligne
        fflush (stdin);
    }

    // crer un nom de fichier temporaire pour le message
    // il a toujours le mme nom pour viter de polluer le
    // rpertoire d'envoi en cas de fausse manoeuvre oprateur
    sprintf (ficmail, "%s/tmp-mes", direnv);

    // Choix de l'diteur de textes
    editeur = getenv ("EDITOR");

    if (! editeur)
        editeur = "vi";

    // saisir le message

    // fabriquer la commande  xcuter
    sprintf (commande, "%s %s", editeur, ficmail);

    // rcuprer l'heure courante
    heuredeb = time (0);

    // lancer la commande
    system (commande);

    // si la commande a rendu la main trs rapidement
    if (time (0) <= heuredeb + 1)
    {
        // "Tapez sur la touche entre en cas d'erreur de lancement de"
        // "l'diteur ou aprs avoir sauv le mail depuis un diteur graphique"
        affiche_msg ("ATTENTE_ENTREE1");
        affiche_msg_nocr ("ATTENTE_ENTREE2");

        // attendre confirmation de l'oprateur
        while (getchar () != '\n')
            ;
    }

    // sortie si arrt de la saisie
    if (access (ficmail, 0) < 0)
        // "Arrt de la saisie par l'oprateur"
        errfatale ("ARRET_SAISIE", 0);

    // charger le carnet d'adresses
    charge_carnet_adr ();

    // crer un nom de fichier temporaire pour l'entte du mail
    sprintf (fentete, "%s/tmp-ent", direnv);

    // fabriquer l'entte du mail de rponse
    gene_entete (sujet, fentete);

    // mmoriser les dates et heure d'envoi du message
    ajout_date (fentete);

    // on va regrouper l'entte et le message dans un fichier numrot dfinitif
    fusionner (fentete, numail, ficmail);

    // ajouter la signature au message, si elle existe
    ajout_sign (ficmail);

    // mettre  jour le fichier numail du rpertoire de sortie
    sauv_num_dermail (direnv, numail);

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}


/* gnre l'entte du mail que l'on transfre */

void gene_entete (char *sujetmail, char *nomfic)
{
    // fabriquer et ouvrir en criture le fichier d'entte
    fdest = fopen (nomfic, "w");

    if (! fdest)
        // "Impossible de crer un fichier d'entte %s"
        errfatale ("IMPOS_CRE_ENTETE", nomfic);

    // rcuprer l'adresse de l'expditeur
    lire_exped ();

    // chercher le numro du mail que l'on va crer
    numail = num_dermail (direnv) + 1;

    // gnration du champ Message-Id
    gen_mes_id (fdest, numail, buf_lect);

    // y copier l'expditeur du message
    ajouts = 0;
    ajout_adr (buf_lect, "From");
    fputc ('\n', fdest);

    // configurer la liaison clavier pour lecture directe avec timeout
    mode_raw ();

    // Choix des destinataires
    debpage ();
    effpage ();

    // "Destinataires principaux"
    affiche_msg_nocr ("PRINCIP_DEST");
    attendre (1);
    choixdest ("To");
    effpage ();

    // "Voulez vous mettre des destinataires en copie ? "
    affiche_msg_nocr ("ACCEPT_DEST_CC");

    if (tolower (leccar ()) != 'n')
    {
        putchar ('\n');
        choixdest ("Cc");
    }
    else
        putchar ('\n');

    effpage ();
    // "Voulez vous mettre des destinataires en copie cache ? "
    affiche_msg_nocr ("ACCEPT_DEST_BCC");

    if (tolower (leccar ()) != 'n')
    {
        putchar ('\n');
        choixdest ("Bcc");
    }

    putchar ('\n');
    effpage ();

    // retour  la configuration standard du clavier
    mode_normal ();

    // gnration du champ Subject
    fprintf (fdest, "Subject: %s", sujetmail);

    // jeu de caractres du message
    fprintf (fdest, "Content-Type: text/plain; charset=");

    if (util_utf8 ())
        fprintf (fdest, "UTF-8;\n");
    else
        fprintf (fdest, "ISO-8859-15;\n");

    // mode d'encodage
    fprintf (fdest, "Content-Transfer-Encoding: 8bit\n");

    // un copyright qui n'est pas celui d'Outlook ;-))
    // "libremail : logiciel libre multilingue"
    fprintf (fdest, "User-Agent: libremail : %s\n",
                     message ("QUALIF_LIBREMAIL"));

    // permettra de relire ce fichier
    fclose (fdest);
}
